@@ -1,5 +1,6 @@
 """Testing application context.."""
 
+import pickle
 from random import randint
 
 import pandas as pd
@@ -14,6 +15,8 @@ from pdpipe.basic_stages import ColDrop
 from pdpipe.util import out_of_place_col_insert
 from pdpipe.core import PdpApplicationContext
 
+from pdptestutil import random_pickle_path
+
 
 def _test_df():
     return pd.DataFrame(
@@ -98,6 +101,19 @@ def test_application_context():
     assert val2 == val
 
 
+def test_application_context_pickling(pdpipe_tests_dir_path):
+    """Testing something."""
+    context = PdpApplicationContext()
+    context.update({'a': 4})
+    fpath = random_pickle_path(pdpipe_tests_dir_path)
+    with open(fpath, 'wb+') as f:
+        pickle.dump(context, f)
+    with open(fpath, 'rb') as f:
+        loaded_context = pickle.load(f)
+
+    loaded_context['b'] = 3
+
+
 def test_application_context_injection():
     """Testing something."""
     drop_char = ColDrop('char')
